@@ -16,7 +16,16 @@ def getSession(request: Request, sessionStorage: SessionStorage = Depends(getSes
     return sessionStorage[sessionId]
 
 
+def getSessionId(request: Request):
+    sessionId = request.cookies.get(config.sessionIdName, "")
+    return sessionId
+
+
 def setSession(response: Response, session: Any, sessionStorage: SessionStorage):
     sessionId = sessionStorage.genSessionId()
     sessionStorage[sessionId] = session
     response.set_cookie(config.sessionIdName, sessionId, httponly=True)
+
+
+def deleteSession(sessionId: str, sessionStorage: SessionStorage):
+    del sessionStorage[sessionId]
